@@ -127,13 +127,11 @@ BVMBug_putchar
 	asm volatile (	"trap #15"
 					: /* no outputs */
 					: "r" (d0), "r" (d1)
-					: "d0", "d1"
 	);
 #else
 	asm volatile (	"jsr (%0)"
 					: /* no outputs */
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1)
-					: "d0", "d1"
 	);
 #endif
 }
@@ -155,13 +153,11 @@ BVMBug_putstr
 	asm volatile (	"trap #15"
 					: /* no outputs */
 					: "r" (d0), "r" (a0)
-					: "d0", "a0"
 	);
 #else
 	asm volatile (	"jsr (%0)"
 					: /* no outputs */
 					: "a" (BVMBugEntry), "r" (d0), "r" (a0)
-					: "d0", "a0"
 	);
 #endif
 }
@@ -185,14 +181,12 @@ BVMBug_print
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (a0), "r" (a1)
-					: "d0", "a0", "a1"
 	);
 
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (a0), "r" (a1)
-					: "d0", "a0", "a1"
 	);
 #endif
 
@@ -220,14 +214,14 @@ BVMBug_format
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (a0), "r" (a1), "r" (a2)
-					: "d0", "a0", "a1", "a2", "memory"
+					: "memory"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (a0),
 										 "r" (a1), "r" (a2)
-					: "d0", "a0", "a1", "a2", "memory"
+					: "memory"
 	);
 #endif
 
@@ -250,13 +244,11 @@ BVMBug_getchar
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0)
-					: "d0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0"
 	);
 #endif
 
@@ -279,13 +271,11 @@ BVMBug_getchar_nowait
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0)
-					: "d0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0"
 	);
 #endif
 
@@ -311,13 +301,11 @@ BVMBug_getstr
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (d1), "r" (a0)
-					: "d0", "d1", "a0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (a0)
-					: "d0", "d1", "a0"
 	);
 #endif
 
@@ -345,13 +333,11 @@ BVMBug_atoi
 	asm volatile (	"trap #15"
 					: "=r" (d0), "=r" (d1)
 					: "r" (d0), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0"
 	);
 #else
 	asm volatile (	"jsr (%2)"
 					: "=r" (d0), "=r" (d1)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0"
 	);
 #endif
 
@@ -377,13 +363,11 @@ BVMBug_malloc
 	asm volatile (	"trap #15"
 					: "=r" (a0)
 					: "r" (d0), "r" (d1)
-					: "d0", "d1", "a0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (a0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1)
-					: "d0", "d1", "a0"
 	);
 #endif
 
@@ -407,13 +391,11 @@ BVMBug_free
 	asm volatile (	"trap #15"
 					: /* no outputs */
 					: "r" (d0), "r" (a0)
-					: "d0", "a0"
 	);
 #else
 	asm volatile (	"jsr (%0)"
 					: /* no outputs */
 					: "a" (BVMBugEntry), "r" (d0), "r" (a0)
-					: "d0", "a0"
 	);
 #endif
 }
@@ -439,13 +421,13 @@ BVMBug_memcmp
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (d1), "r" (a0), "r" (a1)
-					: "d0", "d1", "a0", "a1", "memory"
+					: "memory"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (a0), "r" (a1)
-					: "d0", "d1", "a0", "a1", "memory"
+					: "memory"
 	);
 #endif
 
@@ -473,13 +455,13 @@ BVMBug_memset
 	asm volatile (	"trap #15"
 					: /* no outputs */
 					: "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0", "memory"
+					: "memory"
 	);
 #else
 	asm volatile (	"jsr (%0)"
 					: /* no outputs */
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0", "memory"
+					: "memory"
 	);
 #endif
 }
@@ -505,13 +487,13 @@ BVMBug_memmove
 	asm volatile (	"trap #15"
 					: /* no outputs */
 					: "r" (d0), "r" (d1), "r" (a0), "r" (a1)
-					: "d0", "d1", "a0", "a1", "memory"
+					: "memory"
 	);
 #else
 	asm volatile (	"jsr (%0)"
 					: /* no outputs */
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (a0), "r" (a1)
-					: "d0", "d1", "a0", "a1", "memory"
+					: "memory"
 	);
 #endif
 }
@@ -532,13 +514,11 @@ BVMBug_disk_open
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0)
-					: "d0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0"
 	);
 #endif
 
@@ -566,13 +546,13 @@ BVMBug_disk_read
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0", "memory"
+					: "memory"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0", "memory"
+					: "memory"
 	);
 #endif
 
@@ -595,13 +575,11 @@ BVMBug_disk_close
 	asm volatile (	"trap #15"
 					: /* no outputs */
 					: "r" (d0)
-					: "d0"
 	);
 #else
 	asm volatile (	"jsr (%0)"
 					: /* no outputs */
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0"
 	);
 #endif
 }
@@ -627,13 +605,11 @@ BVMBug_file_open
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0"
 	);
 #endif
 
@@ -661,13 +637,13 @@ BVMBug_file_read
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0", "memory"
+					: "memory"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0", "memory"
+					: "memory"
 	);
 #endif
 
@@ -690,13 +666,11 @@ BVMBug_file_close
 	asm volatile (	"trap #15"
 					: /* no outputs */
 					: "r" (d0)
-					: "d0"
 	);
 #else
 	asm volatile (	"jsr (%0)"
 					: /* no outputs */
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0"
 	);
 #endif
 }
@@ -719,13 +693,11 @@ BVMBug_gettime
 	asm volatile (	"trap #15"
 					: "=r" (d0), "=r" (d1)
 					: "r" (d0)
-					: "d0", "d1"
 	);
 #else
 	asm volatile (	"jsr (%2)"
 					: "=r" (d0), "=r" (d1)
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0", "d1"
 	);
 #endif
 
@@ -754,13 +726,11 @@ BVMBug_define_symbol
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (d2), "r" (a0)
-					: "d0", "d1", "d2", "a0"
 	);
 #endif
 
@@ -784,13 +754,11 @@ BVMBug_delete_symbol
 	asm volatile (	"trap #15"
 					: "=r" (d0)
 					: "r" (d0), "r" (a0)
-					: "d0", "a0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (d0)
 					: "a" (BVMBugEntry), "r" (d0), "r" (a0)
-					: "d0", "a0"
 	);
 #endif
 
@@ -813,14 +781,14 @@ BVMBug_enter
 	asm volatile (	"trap #15"
 					: /* no outputs */
 					: "r" (d0)
-					: "d0", "d1", "d2", "d3", "d4", "d5", "d6",
+					: "d1", "d2", "d3", "d4", "d5", "d6",
 					  "a0", "a1", "a2", "a3", "a4", "memory"
 	);
 #else
 	asm volatile (	"jsr (%0)"
 					: /* no outputs */
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0", "d1", "d2", "d3", "d4", "d5", "d6",
+					: "d1", "d2", "d3", "d4", "d5", "d6",
 					  "a0", "a1", "a2", "a3", "a4", "memory"
 	);
 #endif
@@ -840,14 +808,13 @@ BVMBug_reset
 )
 {
 	asm volatile (
-	"
-		move.w	#0x2700,%%sr	/* mask interrupts							*/
-		move.l	4(%0),%%a0		/* get reset PC								*/
-		move.l	(%0),%%a7		/* get reset SP								*/
-		moveq	#0,%%d0			/* clear cache control register				*/
-		movec	%%d0,%%cacr
-		cinva	%%bc			/* invalidate data and instruction caches	*/
-		jmp		(%%a0)
+	"	move.w	#0x2700,%%sr	| mask interrupts					\n\
+		move.l	4(%0),%%a0		| get reset PC						\n\
+		move.l	(%0),%%a7		| get reset SP						\n\
+		moveq	#0,%%d0			| clear cache control register		\n\
+		movec	%%d0,%%cacr											\n\
+		cinva	%%bc			| invalidate data and instr caches	\n\
+		jmp		(%%a0)												\n\
 	"
 	: /* no outputs */
 	: "a" (BVMBugEntry & 0xff000000)
@@ -880,13 +847,13 @@ BVMBug_tftp_read
 	asm volatile (	"trap #15"
 					: "=r" (d0), "=r" (d1)
 					: "r" (d0), "r" (d1), "r" (d2), "r" (a0), "r" (a1)
-					: "d0", "d1", "d2", "a0", "a1", "memory"
+					: "memory"
 	);
 #else
 	asm volatile (	"jsr (%2)"
 					: "=r" (d0), "=r" (d1)
 					: "a" (BVMBugEntry), "r" (d0), "r" (d1), "r" (d2), "r" (a0), "r" (a1)
-					: "d0", "d1", "d2", "a0", "a1", "memory"
+					: "memory"
 	);
 #endif
 
@@ -910,13 +877,11 @@ BVMBug_netbootinfo
 	asm volatile (	"trap #15"
 					: "=r" (a0)
 					: "r" (d0)
-					: "d0", "a0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (a0)
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0", "a0"
 	);
 #endif
 
@@ -938,13 +903,11 @@ BVMBug_bootargs
 	asm volatile (	"trap #15"
 					: "=r" (a0)
 					: "r" (d0)
-					: "d0", "a0"
 	);
 #else
 	asm volatile (	"jsr (%1)"
 					: "=r" (a0)
 					: "a" (BVMBugEntry), "r" (d0)
-					: "d0", "a0"
 	);
 #endif
 
