@@ -17,9 +17,9 @@
 
 __asm__(".text\n"
 __ALIGN_STR "\n"
-".globl " SYMBOL_NAME_STR(_start) ";\n"
-SYMBOL_NAME_STR(_start) ":\n"
-"	jbra	(" SYMBOL_NAME_STR(Main) ");\n"
+".globl _start;\n"
+"_start:\n"
+"	jbra	(Main);\n"
 );
 
 /*-----------------------------< end of file >------------------------------*/
