@@ -1087,7 +1087,7 @@ add_bi_record
 int
 add_bi_string
 (	unsigned short		tag,
-	const unsigned char	*s
+	const char			*s
 )
 {
     return add_bi_record(tag, strlen(s) + 1, s);
