@@ -260,6 +260,20 @@ mem_move
 
 /*--------------------------------------------------------------------------*/
 
+void *
+memcpy
+(	void			*dest,
+	const void		*srce,
+	unsigned long	count
+)
+{
+	mem_move(dest, srce, count);
+
+	return dest;
+}
+
+/*--------------------------------------------------------------------------*/
+
 int
 mem_cmp
 (	void			*mem1,
@@ -291,10 +305,10 @@ disable_icache
 	{
 		/* disable and invalidate instruction cache */
 		__asm__ __volatile__ (
-		"	movec	%%cacr,%%d1
-			bclr	#15,%%d1
-			movec	%%d1,%%cacr
-			.word	0xf498			| cinva	ic
+		"	movec	%%cacr,%%d1					\n\
+			bclr	#15,%%d1					\n\
+			movec	%%d1,%%cacr					\n\
+			.word	0xf498			| cinva	ic	\n\
 		"
 		: /* no outputs */
 		: /* no inputs */
@@ -318,9 +332,9 @@ enable_icache
 	{
 		/* enable instruction cache */
 		__asm__ __volatile__ (
-		"	movec	%%cacr,%%d1
-			bset	#15,%%d1
-			movec	%%d1,%%cacr
+		"	movec	%%cacr,%%d1		\n\
+			bset	#15,%%d1		\n\
+			movec	%%d1,%%cacr		\n\
 		"
 		: /* no outputs */
 		: /* no inputs */
@@ -344,7 +358,7 @@ invalidate_icache
 	else
 	{
 		__asm__ __volatile__ (
-		"	.word	0xf498		| cinva ic - invalidate instruction cache
+		"	.word	0xf498		| cinva ic - invalidate instruction cache	\n\
 		"
 		);
 	}
@@ -366,22 +380,22 @@ get_cpu_type
 {	int		cpu;
 
 	__asm__ __volatile__ (
-	"	move.w	%%sr,%%d0			| save trace flag
-		movec	%%vbr,%%a0			| get vector table address
-		move.l	0x10(%%a0),%%d1		| save original illegal inst error vector
-		lea.l	1f(%%pc),%%a1		| get new illegal instruction handler
-		move.l	%%a1,0x10(%%a0)		| set it
-		move.l	%%sp,%%a1			| save stack pointer
-		moveq	#60,%%d3			| default: 68060
-		dc.l	0x4e7aa803			| movec	%%msp,%%a2
-		moveq	#40,%%d3			| default: 68040
-		dc.l	0x4e7aa802			| movec %%caar,%%a2
-		moveq	#30,%%d3			| default: 68030
-1:
-		move.l	%%a1,%%sp			| restore stack pointer
-		move.l	%%d1,0x10(%%a0)		| restore original handler
-		move.w	%%d0,%%sr			| restore trace flag
-		move.l	%%d3,%0				| return CPU identifier
+	"	move.w	%%sr,%%d0			| save trace flag						\n\
+		movec	%%vbr,%%a0			| get vector table address				\n\
+		move.l	0x10(%%a0),%%d1		| save original illegal inst vector		\n\
+		lea.l	1f(%%pc),%%a1		| get new illegal instruction handler	\n\
+		move.l	%%a1,0x10(%%a0)		| set it								\n\
+		move.l	%%sp,%%a1			| save stack pointer					\n\
+		moveq	#60,%%d3			| default: 68060						\n\
+		dc.l	0x4e7aa803			| movec	%%msp,%%a2						\n\
+		moveq	#40,%%d3			| default: 68040						\n\
+		dc.l	0x4e7aa802			| movec %%caar,%%a2						\n\
+		moveq	#30,%%d3			| default: 68030						\n\
+1:																			\n\
+		move.l	%%a1,%%sp			| restore stack pointer					\n\
+		move.l	%%d1,0x10(%%a0)		| restore original handler				\n\
+		move.w	%%d0,%%sr			| restore trace flag					\n\
+		move.l	%%d3,%0				| return CPU identifier					\n\
 	"
 	: "=d" (cpu)
 	: /* no inputs */
@@ -404,20 +418,20 @@ get_fpu_type
 {	int		fpu;
 
 	__asm__ __volatile__ (
-	"	move.w	%%sr,%%d0				| save trace flag
-		movec	%%vbr,%%a0				| get vector table address
-		move.l	0x2c(%%a0),%%d1			| save original F-line handler
-		lea.l	1f(%%pc),%%a1			| get new F-line handler
-		move.l	%%a1,0x2c(%%a0)			| set it
-		move.l	%%sp,%%a1				| save stack pointer
-		moveq	#0,%%d3					| default: no FPU
-		dc.l	0xf2800000				| try fnop 
-		moveq	#1,%%d3					| got here, must have FPU
-1:
-		move.l	%%a1,%%sp				| restore stack pointer
-		move.l	%%d1,0x2c(%%a0)			| restore original handler
-		move.w	%%d0,%%sr				| restore trace flag
-		move.l	%%d3,%0					| return FPU fitted status
+	"	move.w	%%sr,%%d0				| save trace flag				\n\
+		movec	%%vbr,%%a0				| get vector table address		\n\
+		move.l	0x2c(%%a0),%%d1			| save original F-line handler	\n\
+		lea.l	1f(%%pc),%%a1			| get new F-line handler		\n\
+		move.l	%%a1,0x2c(%%a0)			| set it						\n\
+		move.l	%%sp,%%a1				| save stack pointer			\n\
+		moveq	#0,%%d3					| default: no FPU				\n\
+		dc.l	0xf2800000				| try fnop 						\n\
+		moveq	#1,%%d3					| got here, must have FPU		\n\
+1:																		\n\
+		move.l	%%a1,%%sp				| restore stack pointer			\n\
+		move.l	%%d1,0x2c(%%a0)			| restore original handler		\n\
+		move.w	%%d0,%%sr				| restore trace flag			\n\
+		move.l	%%d3,%0					| return FPU fitted status		\n\
 	"
 	: "=d" (fpu)
 	: /* no inputs */
@@ -441,29 +455,29 @@ ram_probe
 {	int				rv;
 
 	__asm__ __volatile__ (
-	"	move.w	%%sr,%%d4				| save trace flag
-		movec	%%vbr,%%a0				| get vector table ptr
-		move.l	0x8(%%a0),%%d5			| save BERR vector
-		lea.l	1f(%%pc),%%a1			| new BERR handler
-		move.l	%%a1,0x8(%%a0)			| set it
-		move.l	%%sp,%%a1				| save stack frame
-		moveq	#0,%0					| say no memory here
-		move.l	#0x7e57ed17,%%d1		| get pattern
-		move.l	(%1),%%d2				| save memory
-		move.l	4(%1),%%d3				| save memory + 4
-		move.l	%%d1,(%1)				| store pattern
-		not.l	%%d1					| new pattern
-		move.l	%%d1,4(%1)				| store new pattern, disturb bus
-		not.l	%%d1					| old pattern
-		cmp.l	(%1),%%d1				| did it store
-		bne.s	1f						| branch if not
-		move.l	%%d2,(%1)				| restore memory
-		move.l	%%d3,4(%1)				| restore memory + 4
-		moveq	#1,%0					| say memory found
-1:
-		move.l	%%a1,%%sp				| restore SP
-		move.l	%%d5,0x8(%%a0)			| restore BERR handler
-		move.w	%%d4,%%sr				| restore trace flag
+	"	move.w	%%sr,%%d4				| save trace flag				\n\
+		movec	%%vbr,%%a0				| get vector table ptr			\n\
+		move.l	0x8(%%a0),%%d5			| save BERR vector				\n\
+		lea.l	1f(%%pc),%%a1			| new BERR handler				\n\
+		move.l	%%a1,0x8(%%a0)			| set it						\n\
+		move.l	%%sp,%%a1				| save stack frame				\n\
+		moveq	#0,%0					| say no memory here			\n\
+		move.l	#0x7e57ed17,%%d1		| get pattern					\n\
+		move.l	(%1),%%d2				| save memory					\n\
+		move.l	4(%1),%%d3				| save memory + 4				\n\
+		move.l	%%d1,(%1)				| store pattern					\n\
+		not.l	%%d1					| new pattern					\n\
+		move.l	%%d1,4(%1)				| store new pattern, disturb bus\n\
+		not.l	%%d1					| old pattern					\n\
+		cmp.l	(%1),%%d1				| did it store					\n\
+		bne.s	1f						| branch if not					\n\
+		move.l	%%d2,(%1)				| restore memory				\n\
+		move.l	%%d3,4(%1)				| restore memory + 4			\n\
+		moveq	#1,%0					| say memory found				\n\
+1:																		\n\
+		move.l	%%a1,%%sp				| restore SP					\n\
+		move.l	%%d5,0x8(%%a0)			| restore BERR handler			\n\
+		move.w	%%d4,%%sr				| restore trace flag			\n\
 	"
 	: "=d" (rv)
 	: "a" (where)
@@ -739,7 +753,7 @@ vsoutput
 
 				case 'c':		/* character */
 				{
-					u = (flags & FF_SHORT) ? va_arg(va, unsigned short)
+					u = (flags & FF_SHORT) ? va_arg(va, unsigned int)
 					  : (flags & FF_LONG ) ? va_arg(va, unsigned long )
 				  	  : va_arg(va, unsigned int);
 					*--p = u;
@@ -775,7 +789,7 @@ vsoutput
 					if (c != 'u')
 					{
 						/* signed */
-						n = (flags & FF_SHORT) ? va_arg(va, short)
+						n = (flags & FF_SHORT) ? va_arg(va, int)
 						  : (flags & FF_LONG ) ? va_arg(va, long )
 						  : va_arg(va, int);
 
@@ -788,7 +802,7 @@ vsoutput
 					}
 					else
 					{
-						u = (flags & FF_SHORT) ? va_arg(va, unsigned short)
+						u = (flags & FF_SHORT) ? va_arg(va, unsigned int)
 						  : (flags & FF_LONG ) ? va_arg(va, unsigned long )
 						  : va_arg(va, unsigned int);
 					}
@@ -823,7 +837,7 @@ vsoutput
 
 				case 'x': case 'X':	/* hex, Hex */
 				{
-					u = (flags & FF_SHORT) ? va_arg(va, unsigned short)
+					u = (flags & FF_SHORT) ? va_arg(va, unsigned int)
 					  : (flags & FF_LONG ) ? va_arg(va, unsigned long )
 					  : va_arg(va, unsigned int);
 					do	{
@@ -850,7 +864,7 @@ vsoutput
 
 				case 'o':		/* octal */
 				{
-					u = (flags & FF_SHORT) ? va_arg(va, unsigned short)
+					u = (flags & FF_SHORT) ? va_arg(va, unsigned int)
 					  : (flags & FF_LONG ) ? va_arg(va, unsigned long )
 					  : va_arg(va, unsigned int);
 					do	{
