@@ -214,7 +214,7 @@ void load_symbols (const char *file_name);
 void display_message_file (const char *file_name);
 int check_bootinfo_version (const char *memptr);
 int add_bi_record (unsigned short tag,unsigned short size,const void *data);
-int add_bi_string (unsigned short tag,const unsigned char *s);
+int add_bi_string (unsigned short tag,const char *s);
 int create_bootinfo (void);
 #if BOOTINFO_COMPAT_1_0
 int create_compat_bootinfo (void);
